@@ -1,5 +1,7 @@
 import json
 import tensorflow as tf
+tf.get_logger().setLevel('INFO')
+
 from PIL import Image, ImageDraw
 import os
 import numpy as np 
@@ -527,6 +529,7 @@ def tf_events_to_dict(path, type=''):
     for summary in summary_iterator(path):
         for v in summary.summary.value:
             if not 'image' in v.tag:
+                key = '-'.join(v.tag.split('/'))
                 if v.tag in log_dict.keys():
                     decoded = tf.compat.v1.decode_raw(v.tensor.tensor_content, tf.float32)
                     log_dict[v.tag]["steps"].append(str(len(log_dict[v.tag]["steps"])+1))
